from .base import ApiBase


class ExperimentApi(ApiBase):
    def send(self, experiment_id_or_slug: str, payload: dict):
        path = f"v1/experiments/{experiment_id_or_slug}/events"
        return self._api_call(path, payload)



from .base import ApiBase


class InteractionApi(ApiBase):
    def upload(self, payload: dict):
        return self._api_call('v1/interactions', payload)


    def delete(self, payload: dict):
        return self._api_call('v1/interactions', payload, method='DELETE')



from .base import ApiBase


class QAApi(ApiBase):
    def question_answering(self, payload: dict):
        return self._api_call('v1/qa/question_answering', payload)


    def upload_question_bank(self, payload: dict):
        return self._api_call('v1/qa/questions', payload)


    def question_autocomplete(self, payload: dict):
        return self._api_call('v1/qa/question_autocomplete', payload)



from typing import List

from .base import ApiBase


class SearchApi(ApiBase):
    def search(self, payload: dict):
        return self._api_call('v1/search/search', payload)


    def autocomplete(self, payload: dict):
        return self._api_call('v1/search/autocomplete', payload)


    def multi_get(self, product_ids: List[str]):
        payload = {"product_ids": product_ids}
        return self._api_call('v1/search/mget', payload)



from typing import List

from .base import ApiBase


class RecommendationApi(ApiBase):
    def user_to_products(self, payload: dict):
        return self._api_call('v1/recommendation/user_to_products', payload)


    def user_to_categories(self, payload: dict):
        return self._api_call('v1/recommendation/user_to_categories', payload)


    def user_to_attributes(self, payload: dict):
        return self._api_call('v1/recommendation/user_to_attributes', payload)


    def user_to_trending(self, payload: dict):
        return self._api_call('v1/recommendation/user_to_trending', payload)


    def product_to_products(self, payload: dict):
        return self._api_call('v1/recommendation/product_to_products', payload)



from .base import ApiBase


class ProductApi(ApiBase):
    def upload(self, payload: dict):
        return self._api_call('v1/product', payload)


    def read(self, product_id: str):
        path = f'v1/products/{product_id}'
        return self._api_call(path, {}, method='GET')


    def delete(self, product_id: str):
        path = f'v1/products/{product_id}'
        return self._api_call('v1/product', {}, method='DELETE')



from .base import ApiBase


class UserApi(ApiBase):
    def upload(self, payload: dict):
        return self._api_call('v1/users', payload)


    def read(self, user_id: str):
        path = f'v1/users/{user_id}'
        return self._api_call(path, {}, method='GET')


    def delete(self, user_id: str):
        path = f'v1/users/{user_id}'
        return self._api_call(path, {}, method='DELETE')
